#[non_exhaustive]pub struct CreateContainerRequest {
pub name: String,
pub file_ids: Vec<String>,
pub extra: BTreeMap<String, Value>,
}Expand description
EN: Request body for POST /v1/containers.
中文:POST /v1/containers 的请求体。
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringEN: Container name. 中文:容器名称。
file_ids: Vec<String>EN: Files to copy into the container at creation time. 中文:创建容器时复制到容器内的文件 ID。
extra: BTreeMap<String, Value>EN: Forward-compatible optional fields not yet covered by handwritten types. 中文:手写类型尚未覆盖的前向兼容可选字段。
Implementations
Sourceimpl CreateContainerRequest
impl CreateContainerRequest
Sourcepub fn builder() -> CreateContainerRequestBuilder
pub fn builder() -> CreateContainerRequestBuilder
EN: Starts building a container creation request. 中文:开始构建容器创建请求。