#[non_exhaustive]pub struct RealtimeSessionConfig {
pub kind: String,
pub model: Option<String>,
pub extra: BTreeMap<String, Value>,
}Expand description
EN: Forward-compatible realtime session configuration. 中文:前向兼容的 realtime 会话配置。
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: StringEN: Session kind, for example realtime or transcription.
中文:会话类型,例如 realtime 或 transcription。
model: Option<String>EN: Optional realtime model. 中文:可选的 realtime 模型。
extra: BTreeMap<String, Value>EN: Forward-compatible optional fields not yet covered by handwritten types. 中文:手写类型尚未覆盖的前向兼容可选字段。
Implementations
Sourceimpl RealtimeSessionConfig
impl RealtimeSessionConfig
Sourcepub fn builder(kind: impl Into<String>) -> RealtimeSessionConfigBuilder
pub fn builder(kind: impl Into<String>) -> RealtimeSessionConfigBuilder
EN: Starts building a session config with the documented session type. 中文:使用文档中的会话类型开始构建会话配置。