#[non_exhaustive]pub struct ResponseCodeInterpreterAutoContainer {
pub file_ids: Vec<String>,
pub memory_limit: Option<ResponseCodeInterpreterMemoryLimit>,
pub network_policy: Option<Value>,
/* private fields */
}Expand description
EN: Auto container configuration for a code interpreter tool. 中文:code interpreter 工具的自动容器配置。
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_ids: Vec<String>EN: Uploaded file ids to make available to Python code. 中文:提供给 Python 代码使用的上传文件 ID。
memory_limit: Option<ResponseCodeInterpreterMemoryLimit>EN: Optional memory limit for the container. 中文:容器的可选内存限制。
network_policy: Option<Value>EN: Optional raw network policy for the container. 中文:容器的可选原始网络策略。
Implementations
Sourceimpl ResponseCodeInterpreterAutoContainer
impl ResponseCodeInterpreterAutoContainer
Sourcepub fn file_ids<I, S>(self, file_ids: I) -> Self
pub fn file_ids<I, S>(self, file_ids: I) -> Self
EN: Sets uploaded file ids for the auto container. 中文:设置自动容器可访问的上传文件 ID。
Sourcepub fn memory_limit(
self,
memory_limit: ResponseCodeInterpreterMemoryLimit,
) -> Self
pub fn memory_limit( self, memory_limit: ResponseCodeInterpreterMemoryLimit, ) -> Self
EN: Sets the memory limit for the auto container. 中文:设置自动容器的内存限制。
Sourcepub fn network_policy(self, network_policy: Value) -> Self
pub fn network_policy(self, network_policy: Value) -> Self
EN: Sets raw network policy configuration for the auto container. 中文:设置自动容器的原始网络策略配置。