#[non_exhaustive]pub struct ResponseCodeInterpreterTool {
pub container: ResponseCodeInterpreterContainer,
/* private fields */
}Expand description
EN: Code interpreter tool definition for Responses API built-in Python execution. 中文:Responses API 内置 Python 执行使用的 code_interpreter 工具定义。
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.container: ResponseCodeInterpreterContainerEN: Code interpreter container id or auto container configuration. 中文:code interpreter 容器 ID 或自动容器配置。
Implementations
Sourceimpl ResponseCodeInterpreterTool
impl ResponseCodeInterpreterTool
Sourcepub fn container_id(container_id: impl Into<String>) -> Self
pub fn container_id(container_id: impl Into<String>) -> Self
EN: Creates a code interpreter tool that reuses an existing container id. 中文:创建复用已有容器 ID 的 code_interpreter 工具。
Sourcepub fn auto() -> Self
pub fn auto() -> Self
EN: Creates a code interpreter tool with an automatically managed container. 中文:创建使用自动托管容器的 code_interpreter 工具。
Sourcepub fn auto_container(container: ResponseCodeInterpreterAutoContainer) -> Self
pub fn auto_container(container: ResponseCodeInterpreterAutoContainer) -> Self
EN: Creates a code interpreter tool from an auto container configuration. 中文:使用自动容器配置创建 code_interpreter 工具。
Sourcepub fn file_ids<I, S>(self, file_ids: I) -> Self
pub fn file_ids<I, S>(self, file_ids: I) -> Self
EN: Sets uploaded file ids for the auto container. 中文:设置自动容器可访问的上传文件 ID。
Sourcepub fn memory_limit(
self,
memory_limit: ResponseCodeInterpreterMemoryLimit,
) -> Self
pub fn memory_limit( self, memory_limit: ResponseCodeInterpreterMemoryLimit, ) -> Self
EN: Sets the memory limit for the auto container. 中文:设置自动容器的内存限制。
Sourcepub fn network_policy(self, network_policy: Value) -> Self
pub fn network_policy(self, network_policy: Value) -> Self
EN: Sets raw network policy configuration for the auto container. 中文:设置自动容器的原始网络策略配置。