#[non_exhaustive]pub struct ResponseShellTool {
pub environment: Option<Value>,
/* private fields */
}Expand description
EN: Shell tool definition for Responses API requests. 中文:Responses API 请求使用的 shell 工具定义。
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.environment: Option<Value>EN: Optional shell execution environment. 中文:可选 shell 执行环境。
Implementations
Sourceimpl ResponseShellTool
impl ResponseShellTool
Sourcepub fn new() -> Self
pub fn new() -> Self
EN: Creates a shell tool without an environment hint. 中文:创建不带环境提示的 shell 工具。
Sourcepub fn local() -> Self
pub fn local() -> Self
EN: Creates a shell tool that uses a local environment. 中文:创建使用 local 环境的 shell 工具。
Sourcepub fn container_auto() -> Self
pub fn container_auto() -> Self
EN: Creates a shell tool that automatically creates a container. 中文:创建自动创建 container 的 shell 工具。
Sourcepub fn container_reference(container_id: impl Into<String>) -> Self
pub fn container_reference(container_id: impl Into<String>) -> Self
EN: Creates a shell tool that references an existing container. 中文:创建引用现有 container 的 shell 工具。
Sourcepub fn environment(self, environment: Value) -> Self
pub fn environment(self, environment: Value) -> Self
EN: Sets a raw shell environment object for forward compatibility. 中文:设置原始 shell environment 对象以保持前向兼容。