Client

Struct Client 

pub struct Client { /* private fields */ }
EN: OpenAI SDK client. 中文:OpenAI SDK 客户端。

Implementations

Source

impl Client

pub fn new(api_key: impl Into<String>) -> Result<Self, LingerError>

EN: Creates a client with the default transport. 中文:使用默认传输层创建客户端。

pub fn with_config(config: ClientConfig) -> Result<Self, LingerError>

EN: Creates a client with the provided config and default transport. 中文:使用提供的配置和默认传输层创建客户端。

pub fn with_config_and_transport( config: ClientConfig, transport: SharedTransport, ) -> Self

EN: Creates a client from config and a custom transport. 中文:通过配置和自定义传输层创建客户端。

pub fn responses(&self) -> ResponsesResource

EN: Returns the Responses API resource. 中文:返回 Responses API 资源。

pub fn completions(&self) -> CompletionsResource

EN: Returns the legacy Completions API resource. 中文:返回 legacy Completions API 资源。

pub fn conversations(&self) -> ConversationsResource

EN: Returns the Conversations API resource. 中文:返回 Conversations API 资源。

pub fn realtime(&self) -> RealtimeResource

EN: Returns the Realtime API resource. 中文:返回 Realtime API 资源。

pub fn containers(&self) -> ContainersResource

EN: Returns the Containers API resource. 中文:返回 Containers API 资源。

pub fn evals(&self) -> EvalsResource

EN: Returns the Evals API resource. 中文:返回 Evals API 资源。

pub fn models(&self) -> ModelsResource

EN: Returns the Models API resource. 中文:返回 Models API 资源。

pub fn skills(&self) -> SkillsResource

EN: Returns the Skills API resource. 中文:返回 Skills API 资源。

pub fn videos(&self) -> VideosResource

EN: Returns the Videos API resource. 中文:返回 Videos API 资源。

pub fn batches(&self) -> BatchesResource

EN: Returns the Batches API resource. 中文:返回 Batches API 资源。

pub fn files(&self) -> FilesResource

EN: Returns the Files API resource. 中文:返回 Files API 资源。

pub fn uploads(&self) -> UploadsResource

EN: Returns the Uploads API resource. 中文:返回 Uploads API 资源。

pub fn vector_stores(&self) -> VectorStoresResource

EN: Returns the Vector Stores API resource. 中文:返回 Vector Stores API 资源。

pub fn fine_tuning(&self) -> FineTuningResource

EN: Returns the Fine-tuning API resource. 中文:返回 Fine-tuning API 资源。

pub fn images(&self) -> ImagesResource

EN: Returns the Images API resource. 中文:返回 Images API 资源。

pub fn audio(&self) -> AudioResource

EN: Returns the Audio API resource. 中文:返回 Audio API 资源。

pub fn embeddings(&self) -> EmbeddingsResource

EN: Returns the Embeddings API resource. 中文:返回 Embeddings API 资源。

pub fn moderations(&self) -> ModerationsResource

EN: Returns the Moderations API resource. 中文:返回 Moderations API 资源。

pub fn chat(&self) -> ChatResource

EN: Returns the Chat API resource. 中文:返回 Chat API 资源。

pub fn chatkit(&self) -> ChatKitResource

EN: Returns the ChatKit beta API resource. 中文:返回 ChatKit beta API 资源。

pub fn assistants(&self) -> AssistantsResource

EN: Returns the Assistants API resource. 中文:返回 Assistants API 资源。

pub fn threads(&self) -> ThreadsResource

EN: Returns the Threads API resource. 中文:返回 Threads API 资源。