#[non_exhaustive]pub struct RunStepListRequestBuilder { /* private fields */ }Expand description
EN: Builder for run step list query parameters. 中文:run step 列表查询参数的构建器。
Implementations
Sourceimpl RunStepListRequestBuilder
impl RunStepListRequestBuilder
Sourcepub fn limit(self, limit: u8) -> Self
pub fn limit(self, limit: u8) -> Self
EN: Sets the maximum number of run steps to retrieve. 中文:设置要获取的最大 run step 数量。
Sourcepub fn order(self, order: RunStepListOrder) -> Self
pub fn order(self, order: RunStepListOrder) -> Self
EN: Sets the sort order by creation timestamp. 中文:设置按创建时间戳排序的方向。
Sourcepub fn after(self, after: impl Into<String>) -> Self
pub fn after(self, after: impl Into<String>) -> Self
EN: Sets the cursor after which the next page starts. 中文:设置下一页开始位置之前的游标。
Sourcepub fn before(self, before: impl Into<String>) -> Self
pub fn before(self, before: impl Into<String>) -> Self
EN: Sets the cursor before which the previous page starts. 中文:设置上一页开始位置之后的游标。
Sourcepub fn include_file_search_result_content(self) -> Self
pub fn include_file_search_result_content(self) -> Self
EN: Includes file search result content in step details. 中文:在 step details 中包含 file search 结果内容。
Sourcepub fn build(self) -> Result<RunStepListRequest, LingerError>
pub fn build(self) -> Result<RunStepListRequest, LingerError>
EN: Builds and validates the query parameters. 中文:构建并校验查询参数。