#[non_exhaustive]pub struct ThreadRunListRequestBuilder { /* private fields */ }Expand description
EN: Builder for thread run list query parameters. 中文:thread run 列表查询参数的构建器。
Implementations
Sourceimpl ThreadRunListRequestBuilder
impl ThreadRunListRequestBuilder
Sourcepub fn limit(self, limit: u8) -> Self
pub fn limit(self, limit: u8) -> Self
EN: Sets the maximum number of runs to retrieve. 中文:设置要获取的最大 run 数量。
Sourcepub fn order(self, order: ThreadRunListOrder) -> Self
pub fn order(self, order: ThreadRunListOrder) -> Self
EN: Sets the sort order by creation timestamp. 中文:设置按创建时间戳排序的方向。
Sourcepub fn after(self, after: impl Into<String>) -> Self
pub fn after(self, after: impl Into<String>) -> Self
EN: Sets the cursor after which the next page starts. 中文:设置下一页开始位置之前的游标。
Sourcepub fn before(self, before: impl Into<String>) -> Self
pub fn before(self, before: impl Into<String>) -> Self
EN: Sets the cursor before which the previous page starts. 中文:设置上一页开始位置之后的游标。
Sourcepub fn build(self) -> Result<ThreadRunListRequest, LingerError>
pub fn build(self) -> Result<ThreadRunListRequest, LingerError>
EN: Builds and validates the query parameters. 中文:构建并校验查询参数。